svn commit: r194541 - in head/sys/fs: nfs nfsclient

Rick Macklem rmacklem at FreeBSD.org
Sat Jun 20 17:11:09 UTC 2009


Author: rmacklem
Date: Sat Jun 20 17:11:07 2009
New Revision: 194541
URL: http://svn.freebsd.org/changeset/base/194541

Log:
  Replace RPCAUTH_UNIXGIDS with NFS_MAXGRPS so that nfscbd.c will build.
  
  Approved by:	kib (mentor)

Modified:
  head/sys/fs/nfs/nfs.h
  head/sys/fs/nfsclient/nfs_clport.c

Modified: head/sys/fs/nfs/nfs.h
==============================================================================
--- head/sys/fs/nfsclient/nfs_clport.c	Sat Jun 20 16:45:14 2009	(r194540)
+++ head/sys/fs/nfsclient/nfs_clport.c	Sat Jun 20 17:11:07 2009	(r194541)
@@ -979,7 +979,7 @@ newnfs_copyincred(struct ucred *cr, stru
 	int i;
 
 	nfscr->nfsc_uid = cr->cr_uid;
-	nfscr->nfsc_ngroups = MIN(cr->cr_ngroups, RPCAUTH_UNIXGIDS + 1);
+	nfscr->nfsc_ngroups = MIN(cr->cr_ngroups, NFS_MAXGRPS + 1);
 	for (i = 0; i < nfscr->nfsc_ngroups; i++)
 		nfscr->nfsc_groups[i] = cr->cr_groups[i];
 }


More information about the svn-src-head mailing list
--- head/sys/fs/nfs/nfs.h	Sat Jun 20 16:45:14 2009	(r194540)
+++ head/sys/fs/nfs/nfs.h	Sat Jun 20 17:11:07 2009	(r194541)
@@ -405,12 +405,12 @@ typedef struct {
 
 /*
  * Store uid, gid creds that were used when the stateid was acquired.
  * The RPC layer allows RPCAUTH_UNIXGIDS + 1 groups to go out on the wire,
  * so that's how many gets stored here.
  */
 struct nfscred {
 	uid_t 		nfsc_uid;
-	gid_t		nfsc_groups[RPCAUTH_UNIXGIDS + 1];
+	gid_t		nfsc_groups[NFS_MAXGRPS + 1];
 	int		nfsc_ngroups;
 };
 
@@ -405,12 +405,12 @@ typedef struct {
 /*
  * Store uid, gid creds that were used when the stateid was acquired.
- * The RPC layer allows RPCAUTH_UNIXGIDS + 1 groups to go out on the wire,
+ * The RPC layer allows NFS_MAXGRPS + 1 groups to go out on the wire,
  * so that's how many gets stored here.
  */

Modified: head/sys/fs/nfsclient/nfs_clport.c
==============================================================================